<?php
/** Ladino (Ladino)
 *
 * See MessagesQqq.php for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author ILVI
 * @author Remember the dot
 * @author Runningfridgesrule
 * @author Taichi
 * @author Universal Life
 * @author לערי ריינהארט
 */

$fallback = 'es';

$messages = array(
# User preference toggles
'tog-underline'            => 'Subrayar linkes',
'tog-justify'              => 'Atacanar paragrafos',
'tog-hideminor'            => 'Esconder ediciones chiquiticas de los «trocamientos frescos»',
'tog-showtoolbar'          => 'Amostrár la barra de edision',
'tog-rememberpassword'     => 'Akodrár mis informasiones sobre ésta komputadóra',
'tog-watchcreations'       => 'Vigilar las páginas que estó creando.',
'tog-watchdefault'         => 'Vijilar las pajinas ke yo modifike',
'tog-watchmoves'           => 'Vijilar las pajinas ke renombre',
'tog-watchdeletion'        => 'Vigilar las pajinas ke efase',
'tog-enotifwatchlistpages' => 'Émbiame una letra electrónica kuando ay trocamientos en una página vigilada',
'tog-enotifusertalkpages'  => 'Embiame una pósta kuando troka mi pajina de diskusion de uzuario',
'tog-shownumberswatching'  => 'Amostrár el número de uzuarios ke la vijilan',
'tog-showhiddencats'       => 'Amostrár kategorías eskondidas',

'underline-always' => 'Siempre',
'underline-never'  => 'Nunka',

# Dates
'sunday'        => 'alhád',
'monday'        => 'lúnes',
'tuesday'       => 'mártes',
'wednesday'     => 'miércoles',
'thursday'      => 'djuéves',
'friday'        => 'viérnes',
'saturday'      => 'shabat',
'sun'           => 'Alj',
'mon'           => 'Lun',
'tue'           => 'Mar',
'wed'           => 'Mie',
'thu'           => 'Jug',
'fri'           => 'Vie',
'sat'           => 'Xab',
'january'       => 'Januario',
'february'      => 'Februario',
'march'         => 'Março',
'april'         => 'Abril',
'may_long'      => 'Mayo',
'june'          => 'Junio',
'july'          => 'Julyo',
'august'        => 'Agosto',
'september'     => 'Septiembre',
'october'       => 'Octubre',
'november'      => 'Noviembre',
'december'      => 'Diziembre',
'january-gen'   => 'de Januario',
'february-gen'  => 'de Februario',
'march-gen'     => 'de Março',
'april-gen'     => 'de Abril',
'may-gen'       => 'de Mayo',
'june-gen'      => 'de Junio',
'july-gen'      => 'de Julyo',
'august-gen'    => 'de Agosto',
'september-gen' => 'de Septiembre',
'october-gen'   => 'de Octubre',
'november-gen'  => 'de Noviembre',
'december-gen'  => 'de Diziembre',
'jan'           => 'Jan',
'feb'           => 'Feb',
'mar'           => 'Mar',
'apr'           => 'Abr',
'may'           => 'May',
'jun'           => 'Jun',
'jul'           => 'Jul',
'aug'           => 'Ago',
'sep'           => 'Sep',
'oct'           => 'Oct',
'nov'           => 'Nov',
'dec'           => 'Diz',

# Categories related messages
'category_header'          => 'Artikolos en la kategoría "$1"',
'subcategories'            => 'Subkategorías',
'category-media-header'    => 'Archivos multimedia en la kategoría "$1"',
'category-empty'           => "''La kategoría no kontiene aktualmente ningún artikolo o archivo multimedia''",
'hidden-category-category' => 'Kategorías eskondidas', # Name of the category where hidden categories will be listed
'listingcontinuesabbrev'   => 'kont.',

'about'          => 'Encima de',
'article'        => 'Artikolo',
'newwindow'      => '(Se abre en una ventana nueva)',
'cancel'         => 'Suprimir',
'qbfind'         => 'Buscar',
'qbedit'         => 'Editar',
'qbpageoptions'  => 'Opsiones de pajina',
'qbmyoptions'    => 'Mis opsiones',
'qbspecialpages' => 'Pajinas espesiales',
'moredotdotdot'  => 'Mas...',
'mypage'         => 'Mi pajina',
'mytalk'         => 'Mi diścuśión',
'anontalk'       => 'Diskusion para esta IP',
'and'            => '&#32;e',

'errorpagetitle'   => 'Yerro',
'tagline'          => 'De {{SITENAME}}',
'help'             => 'Ayudo',
'search'           => 'Buscar',
'searchbutton'     => 'Buscar',
'go'               => 'Ir',
'searcharticle'    => 'Yir',
'history'          => 'Istoria',
'history_short'    => 'Istorial',
'info_short'       => 'Informasion',
'printableversion' => 'Versión apropiada para imprimir',
'permalink'        => 'Link mantenido',
'print'            => 'Imprimír',
'edit'             => 'Editar',
'create'           => 'Krear',
'editthispage'     => 'Editar esta página',
'create-this-page' => 'Krear ésta pajina',
'delete'           => 'Efasar',
'deletethispage'   => 'Efasar ésta pajina',
'undelete_short'   => 'Restorar {{PLURAL:$1|una edision|$1 edisiones}}',
'protect'          => 'Abrigár',
'protectthispage'  => 'Abrigar esta página',
'unprotect'        => 'Desabrigar',
'newpage'          => 'Pajina mueva',
'talkpage'         => 'Diścutir esta página',
'talkpagelinktext' => 'Diścutir',
'personaltools'    => 'Aparatos personales',
'postcomment'      => 'Meter un komentário',
'articlepage'      => 'Ver artikolo',
'talk'             => 'Diścuśión',
'views'            => 'Vistas',
'toolbox'          => 'Caxa de Aparatos',
'userpage'         => 'Ver pajina de uzuario',
'viewhelppage'     => 'Ver pajina de ayúda',
'categorypage'     => 'Ver pajina de kategoría',
'viewtalkpage'     => 'Ver diskusion',
'otherlanguages'   => 'En otras linguas',
'redirectedfrom'   => '(Redirigido desde $1)',
'redirectpagesub'  => 'Pajina redirijida',
'protectedpage'    => 'Pajina abrigida',
'jumpto'           => 'Saltar a:',
'jumptonavigation' => 'paśeo',
'jumptosearch'     => 'búsqueda',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'aboutsite'            => 'Encima de {{SITENAME}}',
'aboutpage'            => 'Project:Encima de',
'copyrightpage'        => '{{ns:project}}:Derechos de autor',
'currentevents'        => 'Aktualidad',
'currentevents-url'    => 'Project:Aktualidad',
'disclaimers'          => 'Desmintiras',
'disclaimerpage'       => 'Project:Desmintira general',
'edithelp'             => 'Ayudo de edición',
'edithelppage'         => 'Help:Cómo se edita una página',
'faq'                  => 'FAQ',
'faqpage'              => 'Project:FAQ',
'helppage'             => 'Help:Ayudo',
'mainpage'             => 'Página de Entrada',
'mainpage-description' => 'Página de Entrada',
'policy-url'           => 'Project:Politikas',
'portal'               => 'Portal de la komunidád',
'privacy'              => 'Politika de protección confidencial',
'privacypage'          => 'Project:Politika de protección confidencial',

'badaccess' => 'Falta de permesos',

'ok'              => 'OK',
'retrievedfrom'   => 'Optenido de "$1"',
'newmessageslink' => 'mesajes nuevos',
'editsection'     => 'editar',
'editold'         => 'editar',
'editsectionhint' => 'Editar la columna: $1',
'toc'             => 'Contenidos',
'showtoc'         => 'Amostrar',
'hidetoc'         => 'esconder',
'thisisdeleted'   => 'Ver o restorar $1?',
'viewdeleted'     => 'Desea ver $1?',
'site-rss-feed'   => 'Fuente de RSS de $1',
'site-atom-feed'  => 'Fuente de Atom de $1',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main'      => 'Página',
'nstab-user'      => 'Página de usuario',
'nstab-special'   => 'Espesial',
'nstab-image'     => 'Archivo',
'nstab-mediawiki' => 'Mesaje',
'nstab-help'      => 'Ayudo',
'nstab-category'  => 'Kategoría',

# Main script and global functions
'nosuchspecialpage' => 'No egziste ésta pajina espesial',

# General errors
'error' => 'Yerro',

# Login and logout pages
'yourname'                => 'Su nombre de usuario',
'yourpassword'            => 'Parola',
'nav-login-createaccount' => 'Entrar / Registrarse',
'userlogin'               => 'Entrar / Registrarse',
'logout'                  => 'Salir',
'userlogout'              => 'Salir',
'accountcreated'          => 'Kuenta kreada',
'accountcreatedtext'      => 'La kuenta de uzuario para $1 ha sido kreada.',

# Edit page toolbar
'italic_tip'     => 'Texhto en cursiva',
'extlink_sample' => 'http://www.example.com Título del link',
'headline_tip'   => 'Titular de nivel 2',
'image_tip'      => 'Imagen incorporada',
'media_tip'      => 'Link al arxivo multimedia',

# Edit pages
'summary'          => 'Resumen:',
'subject'          => 'Tema/título:',
'minoredit'        => 'Esta es una edición chiquitica',
'watchthis'        => 'Vigilar este artículo',
'savearticle'      => 'Registrar la página',
'showpreview'      => 'Mostrar la previsualización',
'showdiff'         => 'Amostrar trocamientos',
'accmailtitle'     => 'La kontrasenya ha sido embiada.',
'accmailtext'      => 'La kontrasenya para "$1" se ha embiado a $2.',
'copyrightwarning' => "Si puede ser, que observe que todas las contribuciones a {{SITENAME}} se consideran hechas públicas abaxo la $2 (ver detayes en $1). Si no quere que la gente endereche tus texhtos escritos sin piedad y los distribuya libbremente, alora no los meta aquí. También él/ella nos está asegurando ansí que escribió este texhto su mismo y es dueño de los derechos de autor, o lo copió desde el dominio público u otra fuente libbero.'''¡QUE N0 USE TEXHTOS ESCRITOS CON COPYRIGHT SIN PERMIŚIÓN!'''<br />",

# History pages
'revisionasof'     => 'Rêvizión de $1',
'previousrevision' => '← Rêvizión de antes',
'cur'              => 'act',
'last'             => 'dal cabo',

# Diffs
'lineno'   => 'Liña $1:',
'editundo' => 'deshazer',

# Search results
'searchhelp-url' => 'Help:Ayudo',
'powersearch'    => 'Búsqueda adelantado',

# Preferences page
'preferences'   => 'Preferensias',
'mypreferences' => 'Mis preferencias',

# Recent changes
'recentchanges'   => 'Trocamientos frescos',
'rcnote'          => "Debaxo {{PLURAL:$1|ay '''1''' trocamiento realizado|están los dal cabo '''$1''' trocamientos realizados}} en  {{PLURAL:$2|el dal cabo día|los dal cabo '''$2''' días}}, hasta el $4, $5.",
'rcshowhideminor' => '$1 ediciones chiquiticas',
'rcshowhideliu'   => '$1 usuarios rejistrados',
'rcshowhideanons' => '$1 usuarios anonimos',
'rcshowhidemine'  => '$1 mis edisiones',
'rclinks'         => 'Ver los dal cabo $1 trocamientos en los dal cabo $2 días.<br />$3',
'diff'            => 'dif',
'hist'            => 'ist',
'hide'            => 'Esconder',
'show'            => 'Amostrar',
'minoreditletter' => 'c',
'newpageletter'   => 'N',
'boteditletter'   => 'b',

# Recent changes linked
'recentchangeslinked' => 'Trocamientos conectados',

# Upload
'upload' => 'Cargar un dosyé',

# File description page
'filehist'          => 'Istoria del dosyé',
'filehist-datetime' => 'Data/Hora',
'imagelinks'        => 'Linkes',

# Random page
'randompage' => 'Página por ventura',

# Miscellaneous special pages
'nbytes'       => '$1 {{PLURAL:$1|byte|bytes}}',
'ancientpages' => 'Artikolos mas viejos',
'move'         => 'Trasladar',

# Special:AllPages
'allpages'       => 'Todas las pajinas',
'alphaindexline' => '$1 a $2',
'allarticles'    => 'Todos los artikolos',
'allinnamespace' => 'Todas las pajinas (espasio $1)',
'allpagesnext'   => 'Siguiente',
'allpagessubmit' => 'Amostrar la lista',

# Special:Categories
'categories'                    => 'Kategorías',
'special-categories-sort-count' => 'ordenar por número',
'special-categories-sort-abc'   => 'ordenar alefbeticamente',

# Watchlist
'watchlist'   => 'Mi lista de vigilancia',
'mywatchlist' => 'Mi lista de vigilancia',
'watch'       => 'Vigilar',
'unwatch'     => 'Dexar de vigilar',

# Displayed when you click the "watch" button and it is in the process of watching
'watching'   => 'Vigilando...',
'unwatching' => 'Dexando de vigilar...',

# Delete
'actioncomplete' => 'Aksion kompleta',

# Protect
'prot_1movedto2' => '[[$1]] trasladado a [[$2]]',

# Namespace form on various pages
'blanknamespace' => '(Principal)',

# Contributions
'mycontris' => 'Mis contribuciones',

# What links here
'whatlinkshere'       => 'Lo que se ata con aquí',
'whatlinkshere-links' => '← linkes',

# Block/unblock
'blocklink'    => 'bloquear',
'contribslink' => 'contribuciones',

# Move page
'1movedto2'       => '[[$1]] trasladado a [[$2]]',
'1movedto2_redir' => '[[$1]] trasladado a [[$2]] sovre una redireksion',

# Namespace 8 related
'allmessages'        => 'Mesajes del sistema',
'allmessagesname'    => 'Nombre',
'allmessagesdefault' => 'Teksto por defekto',
'allmessagescurrent' => 'Teksto aktual',

# Thumbnails
'thumbnail-more' => 'Engrandecer',

# Tooltip help for the actions
'tooltip-pt-userpage'     => 'Mi página de usuario',
'tooltip-pt-mytalk'       => 'Mi página de diścuśión',
'tooltip-pt-preferences'  => 'Mis preferencias',
'tooltip-pt-watchlist'    => 'La lista de los trocamientos acontecidos en las páginas vigiladas.',
'tooltip-pt-mycontris'    => 'La lista de mis contribuciones',
'tooltip-pt-login'        => 'Se le aconseja a entrar, ma no es obligado.',
'tooltip-pt-logout'       => 'Salir de la seśión',
'tooltip-ca-talk'         => 'Diścuśión encima del artículo',
'tooltip-ca-edit'         => 'Puede editar esta página. 
Si puede ser, que use el botón de previsualización antes de registrarla.',
'tooltip-search'          => 'Buscar en este viki',
'tooltip-n-mainpage'      => 'Visitar la Página de Entrada',
'tooltip-n-portal'        => 'Encima del proyecto, ¿qué se puede hazer y ánde topar todo?',
'tooltip-n-currentevents' => 'Topar informaciones encima de los acontecimientos actuales',
'tooltip-n-recentchanges' => 'La lista de los trocamientos frescos en el viki',
'tooltip-n-randompage'    => 'Cargar una página por ventura',
'tooltip-n-help'          => 'El lugar para ambezarse',
'tooltip-t-whatlinkshere' => 'La lista de todas las páginas del viki que se atan con ésta',
'tooltip-t-upload'        => 'Mandar imágenes o arxivos de multimedia al servidor',
'tooltip-t-specialpages'  => 'La lista de todas las páginas especiales',
'tooltip-save'            => 'Guardar los trocamientos',
'tooltip-preview'         => 'Que previzualize sus trocamientos, ¡si puede ser, que use esto antes de enregistrar!',
'tooltip-diff'            => 'Mostra los trocamientos que él/ella hizo en el texhto.',

# Attribution
'anonymous' => '{{PLURAL:$1|Uzuario anonimo|Uzuarios anonimos}} de {{SITENAME}}',

# Bad image list
'bad_image_list' => 'El formato es ansina:

Solamente elementos listados (satires que empeçan con *) se aprecian.
El primer link del satir debe de ser un link al foto negro (al que se quere bloquear).
El resto de los linkes del mismo satir se juzgan como eccepciones (por enxemplo, artículos encima de los cualos la foto puede aparecer).',

# EXIF tags
'exif-filesource'   => 'Manadéro de archivo',
'exif-gpstimestamp' => 'Tiémpo GPS (óra atómica)',
'exif-gpsdatestamp' => 'Dáta GPS',

'exif-meteringmode-255' => 'Otro',

'exif-lightsource-9'  => 'Bueno tiémpo',
'exif-lightsource-10' => 'Tiémpo nuvlozo',

# Pseudotags used for GPSSpeedRef and GPSDestDistanceRef
'exif-gpsspeed-k' => 'Kilometros por óra',

# External editor support
'edit-externally' => 'Editar ésto archivo uzándo una aplikasion externa',

# 'all' in various places, this might be different for inflected languages
'recentchangesall' => 'todos',
'imagelistall'     => 'todas',
'watchlistall2'    => 'todos',
'namespacesall'    => 'todos',
'monthsall'        => '(todos)',

# E-mail address confirmation
'confirmemail'         => 'Konfirmar direksion e-pósta',
'confirmemail_send'    => 'Embiar el kodigo de konfirmasion.',
'confirmemail_sent'    => 'Konfirmasion de pósta embiada.',
'confirmemail_success' => 'Su direksion de pósta a sido konfirmada. Agóra puedes registrarse e kolaborar en el wiki.',

# Trackbacks
'trackbackremove' => '([$1 Efasár])',

# Delete conflict
'recreate' => 'Krear de muevo',

# action=purge
'confirm_purge_button' => 'Akseptár',

# Multipage image navigation
'imgmultipageprev' => '← pajina anterior',
'imgmultipagenext' => 'siguiente pajina →',
'imgmultigo'       => 'Ir!',

# Table pager
'table_pager_next'         => 'Pajina siguiente',
'table_pager_prev'         => 'Pajina anterior',
'table_pager_first'        => 'Primera pajina',
'table_pager_last'         => 'Ultima pajina',
'table_pager_limit_submit' => 'Ir',
'table_pager_empty'        => 'No hay resultados',

# Auto-summaries
'autoredircomment' => 'Redireksionado a [[$1]]',
'autosumm-new'     => 'Pajina mueva: $1',

# Special:Version
'version'                  => 'Versión', # Not used as normal message but as header for the special page itself
'version-specialpages'     => 'Pajinas espesiales',
'version-other'            => 'Otros',
'version-version'          => 'Versión',
'version-software-version' => 'Versión',

# Special:FileDuplicateSearch
'fileduplicatesearch-submit' => 'Buscar',

# Special:SpecialPages
'specialpages' => 'Páginas especiales',

);
